@@ -2,8 +2,10 @@ from importlib import import_module
 
 from django.conf import settings
 from django.contrib import admin
+from guardian.admin import GuardedModelAdmin
 from .models import LDPSource, Model
 
+# automatically import selected DjangoLDP packages from settings
 for package in settings.DJANGOLDP_PACKAGES:
     try:
         import_module('{}.admin'.format(package))
@@ -18,9 +20,11 @@ for package in settings.DJANGOLDP_PACKAGES:
 
 model_classes = {cls.__name__: cls for cls in Model.__subclasses__()}
 
+# automatically register models with the admin panel (which have not been added manually)
+# NOTE: by default the models are registered with Django Guardian activated
 for class_name in model_classes:
     model_class = model_classes[class_name]
     if not admin.site.is_registered(model_class):
-        admin.site.register(model_class)
+        admin.site.register(model_class, GuardedModelAdmin)
 
-admin.site.register(LDPSource)
+# admin.site.register(LDPSource)
