@@ -1,10 +1,10 @@
+import uuid
 from collections import OrderedDict, Mapping, Iterable
 from typing import Any
 from urllib import parse
 
 from django.conf import settings
 from django.contrib.auth import get_user_model
-from django.contrib.auth.models import AbstractUser
 from django.core.exceptions import ImproperlyConfigured
 from django.core.exceptions import ValidationError as DjangoValidationError
 from django.core.urlresolvers import get_resolver, resolve, get_script_prefix, Resolver404
@@ -491,13 +491,14 @@ class LDPSerializer(HyperlinkedModelSerializer):
         return serializer
 
     def to_internal_value(self, data):
-        user_case = self.Meta.model is get_user_model() and '@id' in data and not data['@id'].startswith(
+        is_user_and_external = self.Meta.model is get_user_model() and '@id' in data and not data['@id'].startswith(
             settings.BASE_URL)
-        if user_case:
+        if is_user_and_external:
             data['username'] = 'external'
         ret = super().to_internal_value(data)
-        if user_case:
-            ret['username'] = data['@id']
+        if is_user_and_external:
+            ret['urlid'] = data['@id']
+            ret.pop('username')
         return ret
 
     def get_value(self, dictionary):
@@ -562,8 +563,8 @@ class LDPSerializer(HyperlinkedModelSerializer):
                     field_name in validated_data) and not field_name is None:
                 many_to_many.append((field_name, validated_data.pop(field_name)))
         validated_data = self.remove_empty_value(validated_data)
-        if model is get_user_model() and 'urlid' in validated_data and not 'username' in validated_data:
-            validated_data['username'] = validated_data.pop('urlid')
+        if model is get_user_model() and not 'username' in validated_data:
+            validated_data['username'] = uuid.uuid4()
         instance = model.objects.create(**validated_data)
 
         for field_name, value in many_to_many:
@@ -625,9 +626,6 @@ class LDPSerializer(HyperlinkedModelSerializer):
                 elif hasattr(field_model, 'urlid'):
                     kwargs = {'urlid': field_dict['urlid']}
                     sub_inst = field_model.objects.get(**kwargs)
-                elif issubclass(field_model, AbstractUser):
-                    kwargs = {'username': field_dict['urlid']}
-                    sub_inst = field_model.objects.get(**kwargs)
             # try slug field, assuming that this is a local resource
             elif slug_field in field_dict:
                 kwargs = {slug_field: field_dict[slug_field]}
@@ -707,18 +705,18 @@ class LDPSerializer(HyperlinkedModelSerializer):
                 elif slug_field in item:
                     kwargs = {slug_field: item[slug_field]}
                     saved_item = self.get_or_create(field_model, item, kwargs)
-                elif 'urlid' in item and settings.BASE_URL in item['urlid']:
-                    model, old_obj = Model.resolve(item['urlid'])
-                    if old_obj is not None:
-                        saved_item = self.update(instance=old_obj, validated_data=item)
-                    else:
-                        saved_item = self.internal_create(validated_data=item, model=field_model)
-                elif 'urlid' in item and issubclass(field_model, AbstractUser):
-                    kwargs = {'username': item['urlid']}
-                    saved_item = self.get_or_create(field_model, item, kwargs)
                 elif 'urlid' in item:
-                    kwargs = {'urlid': item['urlid']}
-                    saved_item = self.get_or_create(field_model, item, kwargs)
+                    # has urlid and is a local resource
+                    if parse.urlparse(settings.BASE_URL).netloc == parse.urlparse(item['urlid']).netloc:
+                        model, old_obj = Model.resolve(item['urlid'])
+                        if old_obj is not None:
+                            saved_item = self.update(instance=old_obj, validated_data=item)
+                        else:
+                            saved_item = self.internal_create(validated_data=item, model=field_model)
+                    # has urlid and is external resource
+                    elif hasattr(field_model, 'urlid'):
+                        kwargs = {'urlid': item['urlid']}
+                        saved_item = self.get_or_create(field_model, item, kwargs)
                 else:
                     rel = getattr(instance._meta.model, field_name).rel
                     try:
